# Experiment Notebook (`enb`)

The `enb` Python (>= 3.6) library is a table-based framework designed to define, run and report 
computer-based experiments.

- Your can create and run any type of (computer-based) experiment. Quickly.
- You can analyze and plot results produced with your enb experiments. Clearly.
  You can also reuse previously existing data (e.g., in CSV format).
- You can easily create reproducible, redistributable software to be shared with
  others, e.g., as supplementary materials in your publication or project.
- It runs on Linux, Windows and MacOS, in parallel. You can use clusters of Linux or MacOS computers.

## Quickstart resources

- A tutorial-like **user manual** is available at https://miguelinux314.github.io/experiment-notebook.

- Detailed **installation instructions** can be found
  at https://miguelinux314.github.io/experiment-notebook/installation.html.

- The **changelog** between `enb` versions is available
  at https://github.com/miguelinux314/experiment-notebook/blob/master/CHANGELOG.md.

## Installation

The latest stable version of `enb` can be installed by running:

    pip install enb

See detailed **installation instructions** at https://miguelinux314.github.io/experiment-notebook/installation.html.

